.. _irf-energy_dispersion:

Energy dispersion
=================

`~gammapy.irf.EnergyDispersion`

`~gammapy.irf.gauss_energy_dispersion_matrix`

`~gammapy.irf.np_to_rmf`

.. plot:: irf/plot_energy_dispersion.py
